# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 6.1.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.


return <<'END';
002D		
058A		
05BE		
1400		
1806		
2010	2015
2053		
207B		
208B		
2212		
2E17		
2E1A		
2E3A	2E3B
301C		
3030		
30A0		
FE31	FE32
FE58		
FE63		
FF0D		
END
